#
# spec file for package dub
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# DMD is available only on x86*. Use LDC otherwise.
%ifarch %{ix86} x86_64
%bcond_without dcompiler_dmd
%else
%bcond_with dcompiler_dmd
%endif
Name:           dub
Version:        1.23.0
Release:        bp153.1.12
Summary:        Package manager and meta build tool for the D programming language
License:        MIT
Group:          Development/Languages/Other
URL:            https://code.dlang.org
Source:         https://github.com/dlang/dub/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcurl)
%if %{with dcompiler_dmd}
BuildRequires:  dmd
BuildRequires:  phobos-devel
%else
BuildRequires:  ldc
BuildRequires:  ldc-phobos-devel
%endif

%description
Package Manager for the D Programming language.
DUB emerged as a more general replacement for vibe.d's package manager.
It does not imply a dependecy to vibe.d for packages and was extended to
not only directly build projects, but also to generate project files
(currently VisualD). Mono-D also support the use of dub.json
(dub's package description) as project file.

%prep
%autosetup

# reproducible builds:
perl -i -pe 's{__DATE__}{""}g' source/dub/commandline.d

%build
echo Generating version file...
echo "module dub.version_;" > source/dub/version_.d
echo "enum dubVersion = \"%{version}\";" >> source/dub/version_.d

%if %{with dcompiler_dmd}
  dmd -defaultlib=:libphobos2.so \
  -g \
%else
  ldmd2 \
%ifnarch %{arm} %{ix86}
  -g \
%endif
%endif
  -ofbin/dub -w -O \
  -version=DubUseCurl -Isource -L-lcurl @build-files.txt

%install
mkdir -p %{buildroot}%{_bindir}/
install -D -m 755 bin/%{name} %{buildroot}%{_bindir}/

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Sun Dec 27 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to 1.23.0
  * Added architecture x86_omf for windows-dmd
  * dub remove --non-interactive will now remove all packages by default
  * Running dub upgrade on a package-less folder is now a no-op
  * Support dependencies as git url with exact commit
  * All commands now support package[@<version-spec>], --version is deprecated
* Tue May  5 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.20.0 (no changelog)
* Wed Aug 14 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.16.0
  * No changelog was made available.
* Sun Mar 17 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.14.0
  * dub fetch now supports <package>@<version> as a shortcut
  * extraDependencyFiles attribute added
  * File system supplier enabled
  * toolchainRequirements recipe entry
* Mon Feb 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Increase required memory in _constraints as latest ldc requires more RAM
* Fri Jan 25 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM errors
- Fix builds with ldc on %%ix86
* Sat Jan  5 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 1.13.0
  * Add Command
  * dub now supports $DUB variable
  * Pre/Post run commands added
  * Shebang without .d extension
  * Sort JSON
  * Added experimental feature to improve build cache efficiency
* Wed Dec  5 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 1.12.0
  * betterC build option has been added
  * Environment variable DUB_PACKAGE_VERSION added
* Sun Sep  9 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to 1.11.0
  * Variables such as $ARCH or $PLATFORM are now supported in the build settings.
  * DUB supports build type "syntax"
  * Enviroment variable expansion was improved
  * Dependency resolution has been reimplemented using a recursive algorithm
  * DUB accepts single file packages on STDIN
  * The regular upgrade check has been removed
* Thu Aug 30 2018 guillaume.gardet@opensuse.org
- Remove '-g' flag for armv6/armv7 as it breaks the build
* Thu Aug 30 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use LDC compiler when DMD is not available
* Sun Jul  8 2018 matthias.eliasson@gmail.com
- Update to 1.10.0
  * DUB supports "customCachePaths" for providing read-only package paths
* Mon May  7 2018 matthias.eliasson@gmail.com
- Update to 1.9.0
  * No changelog was made available.
- Rename LICENCE.txt to LICENCE
* Mon Apr 16 2018 matthias.eliasson@gmail.com
- Update to 1.8.1
  * Fixed a regression in 1.8.0 that caused linker files specified
    as `sourceFiles` to not get inherited properly
    issue (gh#dlang/dub#1408) pull (gh#dlang/dub#1409)
* Sat Apr 14 2018 matthias.eliasson@gmail.com
- Stop with static linking. Should resolve build issues in openSUSE:Factory
- Remove dependency of git. It is not needed now when we don't use build script
- Generate dub version file
- Set defaultlib to libphobos2.so
* Mon Mar  5 2018 matthias.eliasson@gmail.com
- Update to version 1.8.0
  * No changelog was made available.
* Sun Feb 18 2018 matthias.eliasson@gmail.com
- Update to version 1.7.2
  * more reliable retries and fallback mirror usage - pull (gh#dlang/dub#1339)
* Wed Jan 24 2018 matthias.eliasson@gmail.com
- Update to version 1.7.1
  * Timeout requests to query mirror instead of hanging - pull (gh#dlang/dub#1338)
- Change to %%autosetup rpm macro
* Fri Jan  5 2018 matthias.eliasson@gmail.com
- Update to version 1.7.0
  * No changelog was made available.
- Move LICENCE.txt to %%license macro in %%files section
* Mon Jan  1 2018 matthias.eliasson@gmail.com
- Revert to original build script
* Thu Nov  9 2017 matthias.eliasson@gmail.com
- Update to version 1.6.0
  * The version list displayed for interactive package removal is now sorted
  * File attributes of fetched packages are now preserved
  * http://code-mirror.dlang.io is now used as a fallback for code.dlang.org
  * Failed package downloads are now retried two more times (by Colin Grogan)
- Run spec-cleaner
- Get Dub to complie on i586 with some hints from Arch Linux package.
* Wed Nov  8 2017 jengelh@inai.de
- RPM group fix.
* Sat Jun  3 2017 mailaender@opensuse.org
- update to version 1.3.0
* Fri Mar 24 2017 mailaender@opensuse.org
- Support https://en.opensuse.org/SourceUrls
* Thu Mar  9 2017 matthias.eliasson@gmail.com
- Update to 1.2.2
* Tue Sep 13 2016 kgronlund@suse.com
- Update to 1.0.0
  * Implemented support for single-file packages, including shebang
  script support - issue #103, pull #851, pull #866, pull #870, pull
  [#878]
  * Builds on DMD 2.065.0 up to 2.071.1
  * Removed all deprecated functionality from the API, CLI and data
  formats
  * Switched from std.stream to std.stdio - pull #847
  * Now passes -vcolumns also to LDC - issue #859, pull #860
  * Avoids superfluous registry queries when building - issue #831,
  pull #861
  * Fixed escaping of command line arguments with spaces for LDC -
  issue #834, pull #860
* Sun May  8 2016 jengelh@inai.de
- Eliminate rpmlint-flagged __DATE__
* Sun Jan 24 2016 t.gruner@katodev.de
- Initial Version 0.9.24 - 2015-09
